==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/sites/lang/sites_oc_gsc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=oc_gsc
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'La sindicacion que s’i ei mauescaduda: lo backend indicat qu’ei indeschifrable o non perpausa pas nat article.',
	'avis_echec_syndication_02' => 'La sindicacion que s’i ei mauescaduda: impossible d’accedir au backend d’aqueth sit.',
	'avis_site_introuvable' => 'Sit introbable',
	'avis_site_syndique_probleme' => 'Atencion: la sindicacion d’aqueth sit qu’a encontrat un problèma; lo sistèma qu’ei doncas interromput temporàriament. Verificatz l’adreiça deu fichièr de sindicacion d’aqueth sit (<b>@url_syndic@</b>), e tornatz ensajar de recuperar las informacions.', # MODIF
	'avis_sites_probleme_syndication' => 'Aqueths sits qu’an encontrat un problèma de sindicacion',
	'avis_sites_syndiques_probleme' => 'Aqueths sits sindicats qu’an pausat un problèma',

	// B
	'bouton_radio_modere_posteriori' => 'moderat a posteriòri', # MODIF
	'bouton_radio_modere_priori' => 'moderat a priòri', # MODIF
	'bouton_radio_non_syndication' => 'Nada sindicacion',
	'bouton_radio_syndication' => 'Sindicacion:',

	// E
	'entree_adresse_fichier_syndication' => 'Adreiça deu fichièr "backend" tà la sindicacion:',
	'entree_adresse_site' => '<b>Adreiça deu sit</b> [Obligatòria]',
	'entree_description_site' => 'Descripcion deu sit',

	// F
	'form_prop_nom_site' => 'Nom deu sit',

	// I
	'icone_modifier_site' => 'Modificar aqueth sit',
	'icone_referencer_nouveau_site' => 'Referenciar un sit nau',
	'icone_voir_sites_references' => 'Véder los sits referenciats',
	'info_1_site' => '1 sit',
	'info_a_valider' => '[de validar]',
	'info_bloquer' => 'blocar',
	'info_bloquer_lien' => 'Blocar aqueth ligam',
	'info_derniere_syndication' => 'La darrèra sindicacion d’aqueth sit que’s hasó lo',
	'info_liens_syndiques_1' => 'ligams sindicats',
	'info_liens_syndiques_2' => 'que son en espèra de validacion.',
	'info_nom_site_2' => '<b>Nom deu sit</b> [Obligatòri]',
	'info_panne_site_syndique' => 'Sit sindicat en pana',
	'info_probleme_grave' => 'problèma de',
	'info_question_proposer_site' => 'Qui pòt perpausar sits referenciats?',
	'info_retablir_lien' => 'Restablir aqueth ligam',
	'info_site_attente' => 'Sit web en espèra de validacion',
	'info_site_propose' => 'Sit perpausat lo:',
	'info_site_reference' => 'Sit referenciat en linha',
	'info_site_refuse' => 'Sit web arrefusat',
	'info_site_syndique' => 'Aqueth sit qu’ei sindicat...', # MODIF
	'info_site_valider' => 'Sits de validar',
	'info_sites_referencer' => 'Referenciar un sit',
	'info_sites_refuses' => 'Los sits arrefusats',
	'info_statut_site_1' => 'Aqueth sit qu’ei:',
	'info_statut_site_2' => 'Publicat',
	'info_statut_site_3' => 'Perpausat',
	'info_statut_site_4' => 'A la caisha de las dèishas', # MODIF
	'info_syndication' => 'sindicacion:',
	'info_syndication_articles' => 'article(s)',
	'item_bloquer_liens_syndiques' => 'Blocar los ligams sindicats per validacion',
	'item_gerer_annuaire_site_web' => 'Gerir un annuari de sits web',
	'item_non_bloquer_liens_syndiques' => 'Non blocar pas los ligams gessits de la sindicacion',
	'item_non_gerer_annuaire_site_web' => 'Desactivar l’annuari de sits web',
	'item_non_utiliser_syndication' => 'N’utilizar pas la sindicacion automatica',
	'item_utiliser_syndication' => 'Utilizar la sindicacion automatica',

	// L
	'lien_mise_a_jour_syndication' => 'Actualizar ara',
	'lien_nouvelle_recuperation' => 'Ensajar ua navèra recuperacion de las dadas',

	// S
	'syndic_choix_moderation' => 'Que’s pòt har dab los ligams vienents qui provienen d’aqueth sit?',
	'syndic_choix_oublier' => 'Que’s pòt har dab los ligams qui figuran pas pus dens lo fichièr de sindicacion?',
	'syndic_lien_obsolete' => 'ligam obsolet',
	'syndic_option_miroir' => 'blocà’us suu còp',
	'syndic_option_oubli' => 'escafà’us (après @mois@ mois)',
	'syndic_options' => 'Opcions de sindicacion:',

	// T
	'texte_liens_sites_syndiques' => 'Los ligams gessits deus sits sindicats que’s pòden
   blocar a priòri; lo reglatge
  ça devath qu’indica lo reglatge predefinit deus
   sits sindicats après la lor creacion. De tot mòde,
    qu’ei possible puish de 
   desblocar cada ligam individuaument, o de
   causir, sit per sit, de blocar los ligams avieneders.', # MODIF
	'texte_messages_publics' => 'Messatges publics de l’article:',
	'texte_non_fonction_referencement' => 'Que podetz causir de n’utilizar pas aquera foncion automatica, e indicar deu vòstre sicap los elements qui pertòcan aqueth sit...', # MODIF
	'texte_referencement_automatique' => '<b>Referénciament automatizat d’un sit</b><br /> Que podetz referenciar lèu-lèu un sit web en indicar ça devath l’adreiça URL desirada, o l’adreiça deu son fichièr backend. SPIP que gaharà automaticament las informacions qui concerneishen aqueth sit (títol, descripcion...).', # MODIF
	'texte_syndication' => 'Que’s pòt recuperar automaticament, quora un sit web o permet, 
  la tèra de las soas nautats. Tà har aquò, que’vs cau activar la sindicacion. 
  <blockquote><i>Daubuns aubergaders n’activan pas aquera foncionalitat; 
  en aqueth cas, non poiratz pas utilizar la sindicacion de contengut
  dempuish lo vòste sit.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Articles sindicats tirats d’aqueth sit',
	'titre_dernier_article_syndique' => 'Darrèrs articles sindicats',
	'titre_page_sites_tous' => 'Los sits referenciats',
	'titre_referencement_sites' => 'Referénciament de sits e sindicacion',
	'titre_site_numero' => 'SIT NUMÈRO:',
	'titre_sites_proposes' => 'Los sits perpausats',
	'titre_sites_references_rubrique' => 'Los sits referenciats dens aquera rubrica',
	'titre_sites_syndiques' => 'Los sits sindicats',
	'titre_sites_tous' => 'Los sits referenciats',
	'titre_syndication' => 'Sindicacion de sits'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/sites/lang/sites_oc_gsc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=oc_gsc
// ** ne pas modifier le fichier **

return [

	// A
	'avis_echec_syndication_01' => 'La sindicacion que s’i ei mauescaduda: lo backend indicat qu’ei indeschifrable o non perpausa pas nat article.',
	'avis_echec_syndication_02' => 'La sindicacion que s’i ei mauescaduda: impossible d’accedir au backend d’aqueth sit.',
	'avis_site_introuvable' => 'Sit introbable',
	'avis_site_syndique_probleme' => 'Atencion: la sindicacion d’aqueth sit qu’a encontrat un problèma; lo sistèma qu’ei doncas interromput temporàriament. Verificatz l’adreiça deu fichièr de sindicacion d’aqueth sit (<b>@url_syndic@</b>), e tornatz ensajar de recuperar las informacions.', # MODIF
	'avis_sites_probleme_syndication' => 'Aqueths sits qu’an encontrat un problèma de sindicacion',
	'avis_sites_syndiques_probleme' => 'Aqueths sits sindicats qu’an pausat un problèma',

	// B
	'bouton_radio_modere_posteriori' => 'moderat a posteriòri', # MODIF
	'bouton_radio_modere_priori' => 'moderat a priòri', # MODIF
	'bouton_radio_non_syndication' => 'Nada sindicacion',
	'bouton_radio_syndication' => 'Sindicacion:',

	// E
	'entree_adresse_fichier_syndication' => 'Adreiça deu fichièr "backend" tà la sindicacion:',
	'entree_adresse_site' => '<b>Adreiça deu sit</b> [Obligatòria]',
	'entree_description_site' => 'Descripcion deu sit',

	// F
	'form_prop_nom_site' => 'Nom deu sit',

	// I
	'icone_modifier_site' => 'Modificar aqueth sit',
	'icone_referencer_nouveau_site' => 'Referenciar un sit nau',
	'icone_voir_sites_references' => 'Véder los sits referenciats',
	'info_1_site' => '1 sit',
	'info_a_valider' => '[de validar]',
	'info_bloquer' => 'blocar',
	'info_bloquer_lien' => 'Blocar aqueth ligam',
	'info_derniere_syndication' => 'La darrèra sindicacion d’aqueth sit que’s hasó lo',
	'info_liens_syndiques_1' => 'ligams sindicats',
	'info_liens_syndiques_2' => 'que son en espèra de validacion.',
	'info_nom_site_2' => '<b>Nom deu sit</b> [Obligatòri]',
	'info_panne_site_syndique' => 'Sit sindicat en pana',
	'info_probleme_grave' => 'problèma de',
	'info_question_proposer_site' => 'Qui pòt perpausar sits referenciats?',
	'info_retablir_lien' => 'Restablir aqueth ligam',
	'info_site_attente' => 'Sit web en espèra de validacion',
	'info_site_propose' => 'Sit perpausat lo:',
	'info_site_reference' => 'Sit referenciat en linha',
	'info_site_refuse' => 'Sit web arrefusat',
	'info_site_syndique' => 'Aqueth sit qu’ei sindicat...', # MODIF
	'info_site_valider' => 'Sits de validar',
	'info_sites_referencer' => 'Referenciar un sit',
	'info_sites_refuses' => 'Los sits arrefusats',
	'info_statut_site_1' => 'Aqueth sit qu’ei:',
	'info_statut_site_2' => 'Publicat',
	'info_statut_site_3' => 'Perpausat',
	'info_statut_site_4' => 'A la caisha de las dèishas', # MODIF
	'info_syndication' => 'sindicacion:',
	'info_syndication_articles' => 'article(s)',
	'item_bloquer_liens_syndiques' => 'Blocar los ligams sindicats per validacion',
	'item_gerer_annuaire_site_web' => 'Gerir un annuari de sits web',
	'item_non_bloquer_liens_syndiques' => 'Non blocar pas los ligams gessits de la sindicacion',
	'item_non_gerer_annuaire_site_web' => 'Desactivar l’annuari de sits web',
	'item_non_utiliser_syndication' => 'N’utilizar pas la sindicacion automatica',
	'item_utiliser_syndication' => 'Utilizar la sindicacion automatica',

	// L
	'lien_mise_a_jour_syndication' => 'Actualizar ara',
	'lien_nouvelle_recuperation' => 'Ensajar ua navèra recuperacion de las dadas',

	// S
	'syndic_choix_moderation' => 'Que’s pòt har dab los ligams vienents qui provienen d’aqueth sit?',
	'syndic_choix_oublier' => 'Que’s pòt har dab los ligams qui figuran pas pus dens lo fichièr de sindicacion?',
	'syndic_lien_obsolete' => 'ligam obsolet',
	'syndic_option_miroir' => 'blocà’us suu còp',
	'syndic_option_oubli' => 'escafà’us (après @mois@ mois)',
	'syndic_options' => 'Opcions de sindicacion:',

	// T
	'texte_liens_sites_syndiques' => 'Los ligams gessits deus sits sindicats que’s pòden
   blocar a priòri; lo reglatge
  ça devath qu’indica lo reglatge predefinit deus
   sits sindicats après la lor creacion. De tot mòde,
    qu’ei possible puish de 
   desblocar cada ligam individuaument, o de
   causir, sit per sit, de blocar los ligams avieneders.', # MODIF
	'texte_messages_publics' => 'Messatges publics de l’article:',
	'texte_non_fonction_referencement' => 'Que podetz causir de n’utilizar pas aquera foncion automatica, e indicar deu vòstre sicap los elements qui pertòcan aqueth sit...', # MODIF
	'texte_referencement_automatique' => '<b>Referénciament automatizat d’un sit</b><br /> Que podetz referenciar lèu-lèu un sit web en indicar ça devath l’adreiça URL desirada, o l’adreiça deu son fichièr backend. SPIP que gaharà automaticament las informacions qui concerneishen aqueth sit (títol, descripcion...).', # MODIF
	'texte_syndication' => 'Que’s pòt recuperar automaticament, quora un sit web o permet, 
  la tèra de las soas nautats. Tà har aquò, que’vs cau activar la sindicacion. 
  <blockquote><i>Daubuns aubergaders n’activan pas aquera foncionalitat; 
  en aqueth cas, non poiratz pas utilizar la sindicacion de contengut
  dempuish lo vòste sit.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Articles sindicats tirats d’aqueth sit',
	'titre_dernier_article_syndique' => 'Darrèrs articles sindicats',
	'titre_page_sites_tous' => 'Los sits referenciats',
	'titre_referencement_sites' => 'Referénciament de sits e sindicacion',
	'titre_site_numero' => 'SIT NUMÈRO:',
	'titre_sites_proposes' => 'Los sits perpausats',
	'titre_sites_references_rubrique' => 'Los sits referenciats dens aquera rubrica',
	'titre_sites_syndiques' => 'Los sits sindicats',
	'titre_sites_tous' => 'Los sits referenciats',
	'titre_syndication' => 'Sindicacion de sits',
];
